@@ -10,9 +10,6 @@ import threading
 from concurrent.futures import ThreadPoolExecutor
 from contextlib import contextmanager, closing
 
-from dvc.progress import ProgressCallback
-from dvc.utils import to_chunks
-
 try:
     import paramiko
 except ImportError:
@@ -20,10 +17,12 @@ except ImportError:
 
 import dvc.prompt as prompt
 from dvc.config import Config
+from dvc.utils import to_chunks
 from dvc.utils.compat import urlparse, StringIO
 from dvc.remote.base import RemoteBASE
 from dvc.scheme import Schemes
 from dvc.remote.pool import get_connection
+from dvc.progress import Tqdm
 
 from .connection import SSHConnection
 
@@ -88,6 +87,7 @@ class RemoteSSH(RemoteBASE):
         self.ask_password = config.get(
             Config.SECTION_REMOTE_ASK_PASSWORD, False
         )
+        self.gss_auth = config.get(Config.SECTION_REMOTE_GSS_AUTH, False)
 
     @staticmethod
     def ssh_config_filename():
@@ -96,7 +96,7 @@ class RemoteSSH(RemoteBASE):
     @staticmethod
     def _load_user_ssh_config(hostname):
         user_config_file = RemoteSSH.ssh_config_filename()
-        user_ssh_config = dict()
+        user_ssh_config = {}
         if hostname and os.path.exists(user_config_file):
             ssh_config = paramiko.SSHConfig()
             with open(user_config_file) as f:
@@ -146,6 +146,7 @@ class RemoteSSH(RemoteBASE):
             key_filename=self.keyfile,
             timeout=self.timeout,
             password=self.password,
+            gss_auth=self.gss_auth,
         )
 
     def exists(self, path_info):
@@ -241,7 +242,7 @@ class RemoteSSH(RemoteBASE):
                     if exc.errno != errno.ENOENT:
                         raise
                     ret.append(False)
-                callback.update(path)
+                callback(path)
             return ret
 
         with self.ssh(path_infos[0]) as ssh:
@@ -263,19 +264,19 @@ class RemoteSSH(RemoteBASE):
         faster than current approach (relying on exists(path_info)) applied in
         remote/base.
         """
-        progress_callback = ProgressCallback(len(checksums))
+        if not self.no_traverse:
+            return list(set(checksums) & set(self.all()))
 
-        def exists_with_progress(chunks):
-            return self.batch_exists(chunks, callback=progress_callback)
+        with Tqdm(total=len(checksums), unit="md5") as pbar:
+
+            def exists_with_progress(chunks):
+                return self.batch_exists(chunks, callback=pbar.update_desc)
 
-        if self.no_traverse:
             with ThreadPoolExecutor(max_workers=jobs or self.JOBS) as executor:
                 path_infos = [self.checksum_to_path_info(x) for x in checksums]
                 chunks = to_chunks(path_infos, num_chunks=self.JOBS)
                 results = executor.map(exists_with_progress, chunks)
                 in_remote = itertools.chain.from_iterable(results)
                 ret = list(itertools.compress(checksums, in_remote))
-                progress_callback.finish("")
+                pbar.update_desc("", 0)  # clear path name description
                 return ret
-
-        return list(set(checksums) & set(self.all()))
