@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 
 import os
 import logging
-
+from contextlib import contextmanager
 from itertools import chain
 
 from funcy import cached_property
@@ -17,7 +17,7 @@ from dvc.exceptions import (
 from dvc.ignore import DvcIgnoreFilter
 from dvc.path_info import PathInfo
 from dvc.remote.base import RemoteActionNotImplemented
-from dvc.utils.compat import open as _open, fspath_py35
+from dvc.utils.compat import open as _open, fspath_py35, FileNotFoundError
 from dvc.utils import relpath
 
 logger = logging.getLogger(__name__)
@@ -456,8 +456,16 @@ class Repo(object):
         path_parts = os.path.normpath(path).split(os.path.sep)
         return self.DVC_DIR in path_parts
 
+    @contextmanager
     def open(self, path, remote=None, mode="r", encoding=None):
         """Opens a specified resource as a file descriptor"""
+        try:
+            with self._open(path, remote, mode, encoding) as fd:
+                yield fd
+        except FileNotFoundError:
+            raise OutputFileMissingError(relpath(path, self.root_dir))
+
+    def _open(self, path, remote=None, mode="r", encoding=None):
         out, = self.find_outs_by_path(path)
         if out.isdir():
             raise ValueError("Can't open a dir")
@@ -477,10 +485,6 @@ class Repo(object):
                 cache_info = out.get_used_cache(remote=remote)
                 self.cloud.pull(cache_info, remote=remote)
 
-            # Since pull may just skip with a warning, we need to check it here
-            if not os.path.exists(cache_file):
-                raise OutputFileMissingError(relpath(path, self.root_dir))
-
             return _open(cache_file, mode=mode, encoding=encoding)
 
     @cached_property
